@@ -133,6 +133,8 @@ class BackendBase(implements(BackendInterface)):
         #     cmd = "@" + cmd
 
         if log and self.capture_setup_cmds:
+            assert isinstance(log, str)
+            
             if self.gen_for_windows:
                 cmd = "{} > {}\\__{}__.log".format(cmd, constants.WINDOWS_XT_LOGS, log)
             else:
@@ -306,10 +308,19 @@ class BackendBase(implements(BackendInterface)):
 
     def create_download_commands(self, xt_path, create_dest_dirs, sudo_available, download_requests, 
             for_windows=False, use_username=True):
+        '''
+        Lessons learned here:
+            - we want to create MNT root and subdirectories all without SUDO (so we don't create access for download process 
+              or subsequent reading by normal user)
+              
+            - previously, we were created the MNT folder indirectly thru our blobfuse mounting code, where we create the mapping folder
+              with SUDO.  This created a problem later when we create the download directory, it becomes created with ROOT and then normal
+              user code cannot copy to that folder.
+        '''
         cmds = []
-        username = "$USER"
-        #xt_path = "call " + xt_path if for_windows else xt_path
-        sudo = "sudo " if (sudo_available and not for_windows) else ""
+        #username = "$USER"
+        #sudo = "sudo " if (sudo_available and not for_windows) else ""
+        #sudo = "sudo " if (sudo_available and not for_windows) else ""
 
         # for each mount request
         for md in download_requests:
@@ -328,15 +339,23 @@ class BackendBase(implements(BackendInterface)):
                 else:
                     sub_cmds = \
                     [ 
-                        "{}mkdir -p {}".format(sudo, dest_dir),
+                        # don't use SUDO here; we need dir accessible by current user
+                        "mkdir -p {}".format(dest_dir),
                     ]
-                    if use_username:
-                        sub_cmds.append("{}chown {} {}".format(sudo, username, dest_dir))
+                    # if use_username:
+                    #     sub_cmds.append("{}chown {} {}".format(sudo, username, dest_dir))
 
-                cmds += sub_cmds
+                for sc in sub_cmds:
+                    self.append(cmds, sc)
+
+            # # remove old directory from previous run (singularity doesn't clean these up?)
+            # mc = "{}rm -rf {} ".format(sudo, dest_dir)
+            # self.append(cmds, mc)
 
             cmd = "{} download /{}/{} {}".format(xt_path, container_name, blob_path, dest_dir)
-            self.append(cmds, cmd, True, True)
+            self.append(cmds, cmd, expand=True, log="download")
+
+            self.append_dir(cmds, dest_dir)
 
         return cmds        
 
@@ -344,6 +363,8 @@ class BackendBase(implements(BackendInterface)):
         install_blobfuse, sudo_available, use_username, use_allow_other, 
         nonempty=False, cleanup_needed=False, tmpbase="$HOME", args=None):
 
+        # NOTE: OK to use SUDO here (for blobfuse dirs)
+
         if self.mounting_enabled:
             user_install_blobfuse = args["install_blobfuse"]
             if install_blobfuse and user_install_blobfuse:
@@ -389,16 +410,20 @@ class BackendBase(implements(BackendInterface)):
             self.append_export(cmds, env_var_name, store_data_dir, value_is_windows=self.gen_for_windows)
 
         elif action == "download":
+
+            # keep all DOWNLOAD directories owned by normal user (not ROOT)
+            sudo_available = False
+
             # here, commands must be obey gen_for_windows
             self.append(cmds, "echo DOWNLOADING {} from container {}".format(mnt_path, container))
 
             if gen_for_windows:
-                self.append_export(cmds, env_var_name, store_data_dir, value_is_windows=self.gen_for_windows)
+                self.append_export(cmds, env_var_name, store_data_dir, value_is_windows=True)
+                self.append(cmds, "echo setting {}={}".format(env_var_name, store_data_dir, value_is_windows=True))
             else:
                 full_mnt_path =  mnt_path + "/" + store_data_dir
-                self.append_export(cmds, env_var_name, full_mnt_path, value_is_windows=self.gen_for_windows)
-
-            self.append(cmds, "echo setting {}={}".format(env_var_name, store_data_dir, value_is_windows=self.gen_for_windows))
+                self.append_export(cmds, env_var_name, full_mnt_path, value_is_windows=False)
+                self.append(cmds, "echo setting {}={}".format(env_var_name, full_mnt_path, value_is_windows=False))
 
             # make it look like this is parent dir
             dest_dir_ext = mnt_path + "/" + store_data_dir
@@ -531,7 +556,7 @@ class BackendBase(implements(BackendInterface)):
         # so we reset it to GNU here (to avoid MKL NOT COMPATIBLE error in AML runs)
         self.append(cmds, "echo before setting mkl is $MKL_THREADING_LAYER", echo=False)
         self.append_export(cmds, "MKL_THREADING_LAYER", "GNU")
-         
+
         self.add_info_cmds(cmds, args)
 
         # debug
@@ -562,6 +587,8 @@ class BackendBase(implements(BackendInterface)):
             self.append(cmds, "cd {}".format(cwd))
             self.append(cmds, 'echo current dir: {}'.format("%cd%" if self.gen_for_windows else "$PWD"), echo=False)
 
+            self.append_dir(cmds, ".")
+
         # ensure we have dir for logs
         if self.gen_for_windows:
             self.append(cmds, "md {}".format(constants.WINDOWS_XT_LOGS))
@@ -597,7 +624,8 @@ class BackendBase(implements(BackendInterface)):
             # grep is used to supress the distracting "total" line
             # head is used to limit to 30 lines
             opts = "-R " if recursive else ""
-            cmd = "ls -lt {}{} | grep -vh '^total' | head -n 30".format(opts, path)
+            #cmd = "ls -lt {}{} | grep -vh '^total' | head -n 30".format(opts, path)
+            cmd = "ls -l {}{} | grep -vh '^total'".format(opts, path)
 
         self.append(cmds, cmd, echo=True)
 
@@ -882,6 +910,10 @@ class BackendBase(implements(BackendInterface)):
         workspace = args["workspace"]
         job_id = args["job_id"]
 
+        # create the MNT base folder WITHOUT SUDO
+        # this is required for accessing data/models as normal user
+        self.append(cmds, "mkdir -p {}/.xt/mnt".format(mountbase))
+
         # put mnt paths in user's home dir so sudo isn't needed to create/mount
         if self.mounting_enabled:
             jobs_mount_dir = mountbase + "/.xt/mnt/jobs_container"
@@ -1147,6 +1179,9 @@ class BackendBase(implements(BackendInterface)):
         cmd = 'python -c "from xtlib import node_post_wrapup; node_post_wrapup.main()" '
         self.append(cmds, cmd)
 
+        self.add_node_sleep_cmd(cmds, args)
+
+        self.append(cmds, ":")     # one last command to give us a timestamp for exit
         self.append_title(cmds, 'END of XT-level processing', double=True)
 
         # remove empty cmds
@@ -1287,6 +1322,7 @@ class BackendBase(implements(BackendInterface)):
 
             file_utils.write_text_file(fn_image, full_image_name)
         else:
+            # docker not being used
             # write normal cmds to WRAPPED script
             #insert_index = 1 if self.gen_for_windows else 0
             pre_cmds = []
@@ -1306,6 +1342,13 @@ class BackendBase(implements(BackendInterface)):
         self.fn_wrapped = fn_wrapped
         return fn_wrapped
 
+    def add_node_sleep_cmd(self, cmds, args):
+        sleep_on_exit = args["sleep_on_exit"]
+    
+        if sleep_on_exit:
+            self.append_title(cmds, 'sleeping on exit...', double=True)
+            self.append(cmds, "sleep {}".format(sleep_on_exit))
+
     def write_cmds_to_file(self, cmds, bootstrap_dir, for_windows, fn_bat, fn_sh):
         if for_windows:
             fn_path = bootstrap_dir + "/" + fn_bat
