@@ -676,7 +676,7 @@ class Philly(BackendBase):
                 (keys: workspace, run_name, exper_name, killed, status, before_status)
         '''
         cancel_results = []
-        run_records = run_helper.get_run_records(self.store, workspace, run_names)
+        run_records = run_helper.get_run_records_simple(self.store, workspace, run_names)
 
         for rr in run_records:
             cluster = rr["cluster"]
