@@ -158,7 +158,7 @@ class Singularity(AzureML):
 
         # estimator.run_config.cmk8scompute = k8sconfig
 
-    def run_job_on_singularity(self, experiment, trainer, arg_parts, run_name, args):
+    def run_job_on_singularity(self, experiment, trainer, arg_parts, run_name, node_index, args):
         ws = experiment.workspace
 
         armid = (
@@ -213,7 +213,7 @@ class Singularity(AzureML):
         run = exper.submit(src)
 
         display_name = args["display_name"]
-        display_name = utils.expand_xt_vars(display_name, run_id=run_name, args=args)
+        display_name = utils.expand_xt_vars(display_name, run_id=run_name, node_index=node_index, args=args)
 
         run.display_name = display_name
 
@@ -233,7 +233,7 @@ class Singularity(AzureML):
             sing_run_id = "fake_sing_id"
             sing_run_number = 999
         else:
-            sing_run = self.run_job_on_singularity(experiment, trainer, arg_parts, run_name, args)
+            sing_run = self.run_job_on_singularity(experiment, trainer, arg_parts, run_name, node_index, args)
             sing_run_id = sing_run.id
             sing_run_number = sing_run.number
 
