@@ -6,7 +6,6 @@
 import sys
 import os
 import json
-import xxlimited
 import rpyc
 import copy
 import time
@@ -181,6 +180,7 @@ class XTController(rpyc.Service):
         self.running_jobs = {}
         self.next_run_list_index = 0
         self.stop_processing_runs = False
+        self.total_run_count = 0
 
         self.box_secret = os.getenv("XT_BOX_SECRET")
         self.node_id = os.getenv("XT_NODE_ID")
@@ -290,6 +290,7 @@ class XTController(rpyc.Service):
         self.mrc_context = context
         self.ws_name = context.ws
         self.job_id = context.job_id
+        self.total_run_count = context.total_run_count
 
         self.first_run_index = context.first_run_index
         self.last_run_index = context.last_run_index
@@ -464,15 +465,17 @@ class XTController(rpyc.Service):
         self.store.log_node_event(self.ws_name, self.job_id, self.node_id, 
             "node_end", {"node_id": self.node_id, "run": self.parent_run_name})
 
-        # give other threads time to wrapup the processing of their runs before
-        # we exit
-        if self.sleep_on_exit:
-            log_info("controller sleeping", "{} ...".format(self.sleep_on_exit))
-            # convert from shell time to number of seconds
-            sleep_in_secs = utils.shell_time_str_to_secs(self.sleep_on_exit)
-            time.sleep(sleep_in_secs)
-        else:
-            time.sleep(2)    # wait for 2 secs for any bg thread cleanup
+        # # give other threads time to wrapup the processing of their runs before
+        # # we exit
+        # if self.sleep_on_exit:
+        #     log_info("controller sleeping", "{} ...".format(self.sleep_on_exit))
+        #     # convert from shell time to number of seconds
+        #     sleep_in_secs = utils.shell_time_str_to_secs(self.sleep_on_exit)
+        #     time.sleep(sleep_in_secs)
+        # else:
+        #     time.sleep(2)    # wait for 2 secs for any bg thread cleanup
+
+        time.sleep(2)    # wait for 2 secs for any bg thread cleanup
 
         console.print("controller calling os._exit(0)...")
 
@@ -643,8 +646,8 @@ class XTController(rpyc.Service):
             if self.stop_processing_runs:
                 entry = None
 
-            elif context.search_type == "ccd":
-                # CCD runs are dynamically created on each node (not a fixed count)
+            elif context.schedule == "dynamic":
+                #  runs are dynamically created on each node (not a fixed count)
                 if store_utils.STORAGE_FORMAT == "1":
                     # each node allocates in own 0-relative run_index
                     self.first_run_index = 1
@@ -655,6 +658,11 @@ class XTController(rpyc.Service):
                     # let database allocate next job-level run_index
                     run_index =  self.store.database.get_next_run_index(context.ws, context.job_id)
 
+                    if self.total_run_count and run_index >= self.total_run_count:
+                        # all runs completed; tell controller to exit
+                        self.stop_processing_runs = True
+                        return
+
                 entry = {"status": "unstarted", "run_index": run_index}
 
             elif self.next_run_list_index < len(self.run_indexes):
@@ -833,6 +841,12 @@ class XTController(rpyc.Service):
             else:
                 search_type = None
 
+            # expand display_name for child runs
+            display_name = utils.expand_xt_vars(context.display_name, node_index=self.node_index, 
+                job_id=self.job_id, run_id=child_name)
+
+            print("expanded child display_name from: '{}' to '{}'".format(context.display_name, display_name))
+
             store.start_child_run(context.ws, parent.run_name, context.exper_name,
                 child_name=child_name, 
                 box_name=context.box_name, app_name=context.app_name, path=context.target_file,
@@ -840,7 +854,7 @@ class XTController(rpyc.Service):
                 job_id=context.job_id, pool=context.pool, node_index=self.node_index, 
                 aggregate_dest=context.aggregate_dest,  
                 compute=context.compute, service_type=context.service_type, username=context.username, 
-                search_type=search_type, run_index=run_index, hp_set=hp_set)
+                search_type=search_type, run_index=run_index, hp_set=hp_set, display_name=display_name)
 
             # must update context info
             context.run_name = child_name
@@ -853,10 +867,6 @@ class XTController(rpyc.Service):
             # for CHILD runs, record all "context" (from cmd line, user config, default config) in log (for audit/re-run purposes)
             #store.log_run_event(context.ws, child_name, "context", context.__dict__)
 
-            # get_client_context() should have set this correct for this parent/child run
-            #prep_script = context.child_prep_script     
-            #prep_script = None
-
             child_info = RunInfo(child_name, context.ws, cmd_parts, context.run_script, 
                 None, context, "running", True, parent_name=parent.run_name, mirror_close_func = self.stop_mirror_worker, 
                 node_id=self.node_id, run_index=run_index, store=self.store, is_parent=False)
@@ -1247,7 +1257,8 @@ class XTController(rpyc.Service):
             log_info("downloaded", "{} BEFORE files from JOB STORE".format(len(files)))
 
         log_title("DIR " + rundir)
-        os.system("ls -lt {} | grep -vh '^total' | head -n 30".format(rundir))
+        #os.system("ls -lt {} | grep -vh '^total' | head -n 30".format(rundir))
+        os.system("ls -l {} | grep -vh '^total'".format(rundir))
 
         # HP search generated config.yaml is stored in RUN BEFORE files
         files = capture.download_before_files(store, context.job_id, context.ws, run_name, dest_dir=rundir, silent=True, source="run")
