@@ -38,11 +38,11 @@ def get_command_dicts(prev_exper, curr_exper, browse_flag, browse_opt, timeout_o
 	    {"title": "upload MNIST dataset", "cmd": "xt upload ./data/MNIST/processed/** MNIST/processed --share=data"},
 	    {"title": "upload previously trained MNIST model", "cmd": "xt upload .\models\miniMnist\** miniMnist --share=models"},
 
-	    # RUNS
+	    # RUNS 1-4
 	    {"title": "run script on LOCAL MACHINE", "cmd": "xt run {}--target=local --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
-	    {"title": "run script on ITP-US", "cmd": "xt run {}--target=itp-us --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
+	    {"title": "run script on AML", "cmd": "xt run {}--target=aml --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
 	    {"title": "run script on AZURE BATCH", "cmd": "xt run {}--target=batch --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
-	    {"title": "run script on AZURE ML", "cmd": "xt run {}--target=aml --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
+	    {"title": "run script on SINGULARITY", "cmd": "xt run {}--target=singularity --exper={} code\miniMnist.py".format(monitor_opt, curr_exper)},
 
 	    # REPORTS
 	    {"title": "OVERVIEW: status of jobs", "cmd": "xt list jobs --last=4"},
@@ -86,7 +86,7 @@ def get_command_dicts(prev_exper, curr_exper, browse_flag, browse_opt, timeout_o
 	    #{"title": "view log for run5751", "cmd": "xt view log run5751"}
 	    {"title": "view console output of run2", "cmd": "xt view console run2"},
 
-	    {"title": "download all source code, output, and logs for run4", "cmd": "xt extract run4 {} {}".format(archives_dir, browse_opt)},
+	    {"title": "download all source code, output, and logs for run2", "cmd": 'xt extract run2 "{}" {}'.format(archives_dir, browse_opt)},
 
         # TODO: replace imported runs with new ones; rerun cmd is failing due to trying to use out of date CONFIG file
 	    # RERUN (monitor_opt is harder to apply here)
