@@ -123,6 +123,10 @@ class XTConfig():
         self.create_vault_if_needed()
         return self.vault.get_secret(name)
         
+    def get_vault(self):
+        self.create_vault_if_needed()
+        return self.vault
+
     def create_vault_if_needed(self):
         if not self.vault:
             console.diag("before vault login")
