@@ -127,13 +127,13 @@ class ImplHelp(ImplBase):
         adv = "[advanced mode], " if not self.basic_mode else ""
 
         console.print("  - " + adv + constants.BUILD)
-        console.print("  - Copyright (c) 2020, Microsoft Corporation")
-        console.print("  - Developed by the AML Tools Team")
+        console.print("  - Copyright (c) 2022, Microsoft Corporation")
+        console.print("  - Developed by the MSR Redmond Tools team")
         console.print()
 
         console.print("XT Key Features")
         console.print("  - Scale ML experiments across multiple COMPUTE services:")
-        console.print("      - local machine, VM's, Philly, Azure Batch, Azure AML")
+        console.print("      - local machine, VM's, Azure Batch, Azure AML, Singularity")
         console.print("  - Provide a consistent STORAGE model:")
         console.print("      - workspaces, experiments, jobs, runs")
         console.print("      - blob shares")
@@ -144,15 +144,16 @@ class ImplHelp(ImplBase):
         console.print("XT Design")
         console.print("  - Backend COMPUTE service API")
         console.print("  - Azure Blob Storage (for before/after snapshots, logs, data, models)")
-        console.print("  - Cosmos MongoDB database (for fast, scalable access to stats and metrics)")
-        console.print("  - XT controller app running on all nodes")
+        console.print("  - SQL Server database (for fast, scalable access to stats and metrics)")
+        console.print("  - XT controller app manages runs on all nodes")
         console.print()
 
         console.print("XT Behavior")
-        console.print("  - controlled by hierarichal property settings:")
-        console.print("    - master config file (readonly)")
-        console.print("    - local directory config file")
-        console.print("    - command line options")
+        console.print("  - controlled by hierarichal set of user options:")
+        console.print("    - factory config file (readonly; default XT behavior)")
+        console.print("    - global config file (project-level overrides)")
+        console.print("    - local directory config file (task-specific overrides")
+        console.print("    - command line options (command-specific overrides")
 
     def help_docs(self, browse=False):
         #url = "https://xtdocs.z22.web.core.windows.net/"
@@ -222,7 +223,7 @@ class ImplHelp(ImplBase):
             console.print("  and option keywords can be abbreviated down to 4 letters.")
         else:
             console.print("  XT is used to manage and scale ML experiments.  Jobs can be run on:")
-            console.print("  the local machine, VM's, Philly, Azure Batch, and Azure ML.")
+            console.print("  the local machine, VM's, Azure Batch, Singularity, and Azure ML.")
             console.print()
 
             console.print("  Most command and option keywords can be abbreviated down to 4 letters.")
