@@ -288,10 +288,12 @@ def get_list_jobs_records(store, config, user_columns, args):
     # build a filter dict for all specified filters
     filter_dict = build_job_filter_dict(workspace, job_list, user_to_actual, builder, workspace, args)
 
+    hide_empty_cols = config.get("job-reports", "hide-empty-cols")
+
     # get the db records for the matching JOBS
     #console.print("gathering job data...", flush=True)
     records, limiter, limiter_value = builder.get_db_records(db, filter_dict, workspace, "jobs", actual_to_user, 
-        user_columns=user_columns, args=args)
+        user_columns=user_columns, hide_empty_cols=hide_empty_cols, args=args)
 
     return records, limiter, limiter_value, user_to_actual, builder
 
