@@ -286,10 +286,12 @@ def get_list_nodes_records(store, config, user_columns, args):
     # build a filter dict for all specified filters
     filter_dict = build_node_filter_dict(store, workspace, job_list, user_to_actual, builder, workspace, args)
 
+    hide_empty_cols = config.get("node-reports", "hide-empty-cols")
+
     # get the db records for the matching NODES
     #console.print("gathering job data...", flush=True)
     records, limiter, limiter_value = builder.get_db_records(db, filter_dict, workspace, "nodes", actual_to_user, 
-        user_columns=user_columns, args=args)
+        user_columns=user_columns, hide_empty_cols=hide_empty_cols, args=args)
         
     return records, limiter, limiter_value, user_to_actual, builder
 
