@@ -313,7 +313,7 @@ class ReportBuilder():
 
     def get_db_records(self, database, filter_dict, workspace, which, actual_to_user,
             col_dict=None, col_names_are_external=True, flatten_records=True, need_alive=False, 
-            user_columns=None, args=None):
+            user_columns=None, hide_empty_cols=None, args=None):
 
         started = time.time()
 
@@ -340,6 +340,8 @@ class ReportBuilder():
         group_col = utils.safe_value(args, "group")   
         sort_dir = 1
 
+        user_to_actual = {value: key for key, value in actual_to_user.items()}
+
         # group vs. sort
         if group_col:
             def _get_name(text): 
@@ -379,7 +381,6 @@ class ReportBuilder():
 
             elif not "." in sort_col:
                 # translate name of std col from user-friendly version to logged version
-                user_to_actual = {value: key for key, value in actual_to_user.items()}
 
                 if not sort_col in user_to_actual:
                     errors.general_error("unknown standard property: {} (did you mean metrics.{}, hparams.{}, or tags.{}?)". \
@@ -416,13 +417,16 @@ class ReportBuilder():
 
         started = time.time()
 
+        if hide_empty_cols:
+            hide_empty_cols = [user_to_actual[col] for col in hide_empty_cols]
+
         # here is where DATABASE SERVICE does all the hard work for us
         if which == "runs":
             records = database.get_filtered_sorted_run_info(workspace, filter_dict, col_dict, sort_col, sort_dir, skip, first, 
                 count_runs, buffer_size)
         elif which == "jobs":
             records = database.get_filtered_sorted_job_info(workspace, filter_dict, col_dict, sort_col, sort_dir, skip, first, 
-                count_runs, buffer_size)
+                count_runs, buffer_size, hide_empty_cols)
         elif which == "nodes":
             records = database.get_filtered_sorted_node_info(workspace, filter_dict, col_dict, sort_col, sort_dir, skip, first, 
                 count_runs, buffer_size)
