@@ -126,6 +126,9 @@ class Run():
 
         is_aml_run = bool(os.getenv("AML_WORKSPACE_NAME"))
         
+        # turn off logging to AML (workaround exception in AML on Singularity/TPX)
+        is_aml_run = False
+        
         if is_aml_run:
             # load azure libraries on demand
             from .backends.backend_aml import AzureML
@@ -413,6 +416,10 @@ class Run():
                 if self.store.database:
                     self.store.database.update_run_info(self.ws_name, self.run_name, ddx)
 
+        else:
+            # local machine run; ensure dd is persistable
+            dummy = json.dumps(dd)
+            
         # log to AML
         if self.is_aml and self.aml_logging:
             for name, value in dd.items():
