@@ -463,11 +463,13 @@ def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None,
 
     highight_exp = config.get("run-reports", "highlight") 
     need_alive = highight_exp == "$alive"
+    hide_empty_cols = config.get("run-reports", "hide-empty-cols")
 
     # get the db records for the matching RUNS
     records, limiter, limiter_value = builder.get_db_records(db, filter_dict, workspace, which="runs", 
         actual_to_user=actual_to_user, col_dict=col_dict, col_names_are_external=col_names_are_external, 
-        flatten_records=flatten_records, need_alive=need_alive, user_columns=user_columns, args=args)
+        flatten_records=flatten_records, need_alive=need_alive, user_columns=user_columns, hide_empty_cols=hide_empty_cols, 
+        args=args)
 
     # remove key info from _id in records
     store_utils.simplify_records_id(records)
