@@ -164,7 +164,7 @@ class StoreV2():
         if not db_creds and config:
             db_creds = config.get_database_creds()
 
-        self.max_log_workers = utils.safe_value(db_options, "max-log-workers")
+        self.max_log_workers = utils.safe_value(db_options, "max-log-workers", 10)
 
         if config:
             if not storage_creds:
@@ -607,7 +607,7 @@ class StoreV2():
     def start_child_run(self, ws_name, parent_run_name, exper_name=None, cmd_line_args=None, all_args=None, description=None, 
             from_ip=None, from_host=None, app_name=None, repeat=None, box_name="local", job_id=None, pool=None, 
             node_index=None, username=None, aggregate_dest=None, path=None, child_name=None, compute=None, 
-            service_type=None, search_type=None, sku=None, search_style=None, run_index=None, hp_set=None):
+            service_type=None, search_type=None, sku=None, search_style=None, run_index=None, hp_set=None, display_name=None):
         '''
         This is usually called from the XT COMPUTE box, so we CANNOT get from_ip and from_computer_name from the local machine.
         '''
@@ -626,7 +626,7 @@ class StoreV2():
         self.start_run_core(ws_name, child_name, exper_name=exper_name, description=description, username=username,
             box_name=box_name, app_name=app_name, repeat=None, is_parent=False, job_id=job_id, pool=pool, node_index=node_index,
             aggregate_dest=aggregate_dest, path=path, aml_run_id=None, compute=compute, service_type=service_type, search_type=search_type,
-            sku=sku, search_style=search_style, is_child=True, run_index=run_index, hp_set=hp_set)           
+            sku=sku, search_style=search_style, is_child=True, run_index=run_index, hp_set=hp_set, display_name=display_name)           
 
         # finally, add a "child_created" record to the parent
         self.log_run_event(ws_name, parent_run_name, "child_created", {"child_name": child_name}, job_id=job_id)
@@ -634,7 +634,7 @@ class StoreV2():
     def start_run_core(self, ws_name, run_name, exper_name=None, description=None, username=None,
             box_name=None, app_name=None, repeat=None, is_parent=False, job_id=None, pool=None, node_index=None,
             aggregate_dest="none", path=None, aml_run_id=None, compute=None, service_type=None, search_type=None,
-            sku=None, search_style=None, is_child=False, run_index=None, tag_dict=None, hp_set=None):
+            sku=None, search_style=None, is_child=False, run_index=None, tag_dict=None, hp_set=None, display_name=None):
 
         console.diag("start_run: after create_next_run_directory")
 
@@ -668,6 +668,7 @@ class StoreV2():
             "compute": compute, 
             "create_time": create_time,
             "description": description, 
+            "display_name": display_name,
             "exper_name": exper_name, 
             "from_ip": ip, 
             "from_computer_name": hostname, 
@@ -1027,8 +1028,8 @@ class StoreV2():
 
     #---- LOW LEVEL ----
             
-    def list_blobs(self, container, blob_path, return_names=True):
-        return self.helper.list_blobs(container, blob_path, return_names=return_names)
+    def list_blobs(self, container, blob_path, return_names=True, recursive=True):
+        return self.helper.list_blobs(container, blob_path, return_names=return_names, recursive=recursive)
 
     # ---- RUN FILES ----
 
