@@ -12,11 +12,12 @@ import logging
 import numpy as np
 from interface import implements
 
-# # debug
+# restore azure-storage-blob for this module
+# os.system("pip install azure-storage-blob==2.1.0")
 # import azure.storage.blob as bb
 # print("azure blob storage version: ", bb.__version__)
 
-from azure.storage.blob import AppendBlobService, BlockBlobService, PublicAccess
+from azure.storage.blob import AppendBlobService, BlockBlobService
 
 from xtlib import utils
 from xtlib import errors
@@ -172,7 +173,13 @@ class AzureBlobStore21(implements(StoreInterface)):
     def does_blob_exist(self, container, blob_path):
         self._container_check(container, create_if_needed=False)
 
-        return self.bs.exists(container, blob_path)
+        exists = self.bs.exists(container, blob_path)
+        if exists:
+            # check its size (hide 0-length blobs (pseudo-folders) that cause XT problems)
+            blob = self.bs.get_blob_properties(container, blob_path)
+            exists = blob.properties.content_length > 0
+
+        return exists
 
     def create_blob(self, container, blob_path, text, fail_if_exists=False, etag=None):
         self._container_check(container, create_if_needed=True)
@@ -243,56 +250,45 @@ class AzureBlobStore21(implements(StoreInterface)):
         if not succeeded:
             errors.service_error("_append_blob_with_rewrite failed (too many retries)")
 
-
-    def list_blobs(self, container, path=None, return_names=True, recursive=True):
+    def list_blobs(self, container, path=None, return_names=True, recursive=False):
         '''
-        NOTE: the semantics here a tricky
+        Lessons learned from tryout/blob_v21_test.py:
 
-        if recursive:
-            - return a flat list of all full path names of all files (no directory entries)
-        else: 
-            - return a flat list of all files and all directory names (add "/" to end of directory names)
+            delimiter:
+                use None or "" for recursive list
+                use "/" to current list to current directory
 
-        if return_names:
-            - return list of names
-        else:
-            - return a list of objects with following properties:
-                .name     (file pathname)
-                .properties
-                    .content_length   (number)
-                    .modified_ns      (time in ns)
+            path:
+                if matches a blob's path, will return BLOB 
+                if matches a folder, will return PREFIX 
+                if matches a folder BUT ends with "/", return contents of that folder
 
-        The delimiter trick: this is when we set the delimiter arg = "/" to tell azure to return only the blobs 
-        in the specified directory - that is, don't return blobs from child directories.  In this case, azure 
-        returns the effective child directory name, followed by a "/", but not its contents (which we hope is faster).
-        '''
+            for XT:
+                - if wildcard found, remove trailing "/" from path (so we match current dir)
+                - if a PREFIX is returned that matches PATH, call again adding "/" to end of path (to get contents of directory)
+        ''' 
         self._container_check(container, create_if_needed=True)
-
         delimiter = None if recursive else "/"
 
-        # specific Azure path rules for good results
-        if path:
-            if path.startswith("/"):
-                path = path[1:]     # blob API wants this part of path relative to container
-
-            # we should only add a "/" if path is a folder path
-            if path.endswith("*"):
-                # we just need to block the addition of "/"
-                path = path[0:-1]
-            elif not path.endswith("/"):
-                # if self.bs.exists(container, path):
-                #     # special case for "list" of a single blob
-                #     pass
-                # else:
-                #     path += "/"         # treat as directory
-                path += "/"     # treat as directory
-
         blobs = self.bs.list_blobs(container, prefix=path, delimiter=delimiter)
+        blobs = list(blobs)
+
+        if len(blobs)==1:
+            blob = blobs[0]
+            if blob.name.endswith("/") and blob.name[:-1] == path and (not hasattr(blob, "properties")):
+                # we received a single PREFIX object that matched our path
+                # try again with slash at end of path to get dir contents
+                path = blob.name
+                blobs = self.bs.list_blobs(container, prefix=path, delimiter=delimiter)
+
+        # check size of each blob (hide 0-length blobs (pseudo-folders) that cause XT problems)
+        # watch out: some of returned blobs are "blob_prefix" objects (folders)
+        #blobs = [blob for blob in blobs if hasattr(blob, "properties") and blob.properties.content_length > 0] 
+        blobs = [blob for blob in blobs if (not hasattr(blob, "properties")) or (blob.properties.content_length > 0)] 
 
         if return_names:
             blobs = [blob.name for blob in blobs]
-        else:
-            blobs = list(blobs)
+
         return blobs
 
     def delete_blob(self, container, blob_path, snapshot=None):
