@@ -16,7 +16,7 @@ from xtlib import console
 from xtlib import pc_utils
 from xtlib import constants
 from xtlib import file_utils
-from xtlib.cache_client import CacheClient
+#from xtlib.cache_client import CacheClient
 
 class XTVault():
 
@@ -27,9 +27,10 @@ class XTVault():
         self.authentication = None
         self.keys = None
         self.secret_name = secret_name
+        self.credential = None
 
     def init_creds(self, authentication):
-        cache_client = CacheClient()
+        cache_client = None    # CacheClient()
         loaded = False
         self.authentication = authentication
 
@@ -38,12 +39,12 @@ class XTVault():
             loaded = self._load_node_creds()
         if not loaded and self.vault_url:
             # normal XT client
-            creds = cache_client.get_creds(self.store_name)
+            creds = None    # cache_client.get_creds(self.store_name)
             if creds:
                 self.apply_creds(creds)
             else:
                 creds = self._get_creds_from_login(authentication, reason="cache not set")
-                cache_client.store_creds(self.store_name, creds)
+                #cache_client.store_creds(self.store_name, creds)
 
     def _load_grok_creds(self):
         fn_keys = "keys.bin"
@@ -88,34 +89,76 @@ class XTVault():
 
         return loaded
 
+    def get_creds_core(self, authentication):
+        used_browser = False
+
+        if not self.credential:
+            from azure.identity import InteractiveBrowserCredential, TokenCachePersistenceOptions, AuthenticationRecord
+
+            # open the serialized azure authentication record (contains no secrets)
+            dir_name = file_utils.get_xthome_dir()
+            fn = dir_name + "/azure_cred_cache.txt"        
+            deserialized_record = None
+
+            if os.path.exists(fn):
+                with open(fn, "rt") as infile:
+                    cred_json = infile.read()
+                    deserialized_record = AuthenticationRecord.deserialize(cred_json)
+
+            if authentication == "auto":
+                authentication = "browser" if pc_utils.has_gui() else "device-code"
+
+            if authentication == "browser":
+                if not deserialized_record:
+                    console.print("authenticating with azure thru browser... ", flush=True, end="")
+                    used_browser = True
+                
+                cpo = TokenCachePersistenceOptions()
+                credential = InteractiveBrowserCredential(cache_persistence_options=cpo,
+                    authentication_record=deserialized_record)
+
+            elif authentication == "device-code":
+                '''
+                This apparently does NOT support caching.  We can't make user authenticate
+                thru browser on separate machine every time he wants to run an XT command.
+                '''
+                # console.print("authenticating with azure thru device code... ", flush=True, end="")
+                from azure.identity import DeviceCodeCredential
+
+                console.print("using device-code authorization")
+                credential = DeviceCodeCredential() 
+
+            else:
+                errors.syntax_error("unrecognized authentication type '{}'".format(authentication))
+
+            if not deserialized_record:
+                # serialize to our cred to disk
+                record = credential.authenticate()
+                cred_json = record.serialize()
+
+                with open(fn, "wt") as outfile:
+                    outfile.write(cred_json)
+
+            self.credential = credential
+
+        return self.credential, used_browser
+
     def _get_creds_from_login(self, authentication, reason=None):
 
         # use normal Key Value
         from azure.keyvault.secrets import SecretClient
         #from azure.identity import DefaultAzureCredential
 
-        if authentication == "auto":
-            authentication = "browser" if pc_utils.has_gui() else "device-code"
-
-        if authentication == "browser":
-            console.print("authenticating with azure thru browser... ", flush=True, end="")
-            from azure.identity import InteractiveBrowserCredential
-            credential = InteractiveBrowserCredential()  
-        elif authentication == "device-code":
-            # console.print("authenticating with azure thru device code... ", flush=True, end="")
-            from azure.identity import DeviceCodeCredential
-            from azure.identity._constants import AZURE_CLI_CLIENT_ID 
-
-            console.print("using device-code authorization (Azure AD currently requires 2-4 authenications here)")
-            credential = DeviceCodeCredential(client_id=AZURE_CLI_CLIENT_ID)  
-        else:
-            errors.syntax_error("unrecognized authentication type '{}'".format(authentication))
+        credential, used_browser = self.get_creds_core(authentication)
 
         new_creds = True
-        scopes = ""
-        outer_token = credential.get_token(scopes)
+        scope = "https://management.core.windows.net/.default"
+        outer_token = credential.get_token(scope)
         token = outer_token.token
 
+        if used_browser:
+            console.print("authenticated successfully", flush=True)
+
         # expires = outer_token[1]
         # elapsed = expires - time.time()
         #print(" [new token expires in {:.2f} mins] ".format(elapsed/60), end="")
@@ -123,7 +166,6 @@ class XTVault():
         # get keys from keyvault
         self.client = SecretClient(self.vault_url, credential=credential)
         key_text = self.get_secret_live(self.secret_name)
-        console.print("authenticated successfully", flush=True)
 
         #xt_client_cert = self.get_secret_live("xt-clientcert")
         xt_server_cert = self.get_secret_live("xt-servercert")
@@ -132,7 +174,9 @@ class XTVault():
         self.apply_creds(key_text)
         self.keys["xt_server_cert"] = xt_server_cert
 
-        self.keys["object_id"] = self.get_me_graph_property(token, "id")
+        # for some reason, credentials returned from InteractiveBrowserCredential w/serialization
+        # no longer works for this AAD call
+        #self.keys["object_id"] = self.get_me_graph_property(token, "id")
 
         # return creds as json string
         return json.dumps(self.keys)
